let native = null;
let err = null;
if (native == null) {
  try {
    native = require("./linux_arm64/koffi.node");
  } catch (e) {
    err = e;
  }
}
if (native == null) {
  try {
    native = require("./musl_arm64/koffi.node");
  } catch (e) {
    err = e;
  }
}
if (native == null)
  throw err;
module.exports = native;
